@@ -11,12 +11,13 @@ our $VERSION;
 # $VERSION declaration must stay up here, ahead of any other package
 # declarations, as to not confuse various modules attempting to determine
 # this ones version, whether that be s.c.o. or Module::Metadata, etc
-$VERSION = '0.08193_01';
+$VERSION = '0.08195_01';
 
 $VERSION = eval $VERSION if $VERSION =~ /_/; # numify for warning-free dev releases
 
 BEGIN {
-  package DBIx::Class::_ENV_;
+  package # hide from pause
+    DBIx::Class::_ENV_;
 
   if ($] < 5.009_005) {
     require MRO::Compat;
